<script setup>
import Checkbox from '@/Components/Checkbox.vue';
import GuestLayout from '@/Layouts/GuestLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import { Head, Link, useForm } from '@inertiajs/vue3';

defineProps({
    canResetPassword: {
        type: Boolean,
    },
    status: {
        type: String,
    },
});

const form = useForm({
    email: '',
    password: '',
    remember: false,
});

const submit = () => {
    form.post(route('login'), {
        onFinish: () => form.reset('password'),
    });
};
</script>

<template>
    <div class="wrapper-login min-h-screen justify-content-center align-items-center d-flex">
        <div class="container">
            <div class="login-inner">
                <div class="row justify-content-center rounded-md overflow-hidden ">
                    <div class="col-lg-6 col-md-6 col-sm-12 col-12 login-block">
                        <div class="login-form">
                            <GuestLayout>
                                <Head title="Log in" />
                                <h2 class="text-xl text-center mb-4">Welcome to Login</h2>
                                <div v-if="status" class="mb-4 font-medium text-sm text-center text-green-600">
                                    {{ status }}
                                </div>

                                <form @submit.prevent="submit" class="z-3">

                                    <div >
                                        <!-- <InputLabel for="email" value="Email" /> -->

                                        <TextInput
                                            id="email"
                                            type="email"
                                            placeholder="Email"
                                            class="mt-1 block w-full"
                                            v-model="form.email"
                                            required
                                            autofocus
                                            autocomplete="username"
                                        />

                                        <InputError class="mt-2" :message="form.errors.email" />
                                    </div>

                                    <div class="mt-4">
                                        <!-- <InputLabel for="password" value="Password" /> -->

                                        <TextInput
                                            id="password"
                                            type="password"
                                            placeholder="Password"
                                            class="mt-1 block w-full"
                                            v-model="form.password"
                                            required
                                            autocomplete="current-password"
                                        />

                                        <InputError class="mt-2" :message="form.errors.password" />
                                    </div>

                                    <div class="block mt-4">
                                        <label class="flex items-center">
                                            <Checkbox name="remember" v-model:checked="form.remember" id="rememberme" />
                                            <label for="rememberme" class="ms-2 text-md text-gray">Remember me</label>
                                        </label>
                                    </div>

                                    <div class="flex items-center justify-end mt-4">
                                        <Link
                                            v-if="canResetPassword"
                                            :href="route('password.request')"
                                            class="underline text-sm text-gray hover:text-gray-900 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                                        >
                                            Forgot your password?
                                        </Link>

                                        <PrimaryButton class="btn login-btn" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                                            Log in
                                        </PrimaryButton>
                                    </div>
                                </form>
                            </GuestLayout>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-6 col-sm-12 col-12 login-block login-block-thumb">
                        <div class="section-thumb">
                            <img src="/assets/images/windshield-change.png" alt="">
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</template>
